==> designer-asset-1.0.10-20251126.015304-8-sources.jar: com/digiwin/athena/mongodb/domain/assetType/AssetType.java <==
package com.digiwin.athena.mongodb.domain.assetType;

import com.alibaba.fastjson.JSONObject;
import com.digiwin.athena.dto.action.MultiLanguageDTO;
import com.digiwin.athena.mongodb.domain.ApiInfo;
import com.digiwin.athena.mongodb.domain.DataCollectConfig;
import com.digiwin.athena.mongodb.domain.PublishAble;
import lombok.Data;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 资产类型
 */
@Data
@Document(collection = "assetType")
public class AssetType implements PublishAble {

    //草稿draft、已上架online、已下架offline
    public static final String STATUS_DRAFT = "draft";
    public static final String STATUS_ONLINE = "online";
    public static final String STATUS_OFFLINE = "offline";

    @Id
    private String objId;

    private String type;

    private String name;

    private String version="1.0";

    /**
     * 大类
     */
    private String category;

    /**
     * 资产归属
     */
    private String owner;

    /**
     * status|草稿draft、已上架online、已下架offline
     */
    private String status;

    private String description;

    private String docUrl;

    private String icon;

    /**
     * 资产操作api
     */
    private List<ApiInfo> apiList;

    private List<ApiInfo> openApiList;

    private JSONObject metadata;

    private Date publishTime;

    private List<JSONObject> dependencyRule;
    private List<JSONObject> manageContextRule;
    private DataCollectConfig dataCollectConfig;
    private Map<String, MultiLanguageDTO> lang;

    private JSONObject rowDataPermission;

    private String createBy;
    private String editBy;
    private Date createDate;
    private Date editDate;

    private Boolean canReference = false;
    /**
     * 能否复制
     */
    private Boolean canCopy = false;

}

==> designer-asset-1.0.10-20251202.094748-22-sources.jar: com/digiwin/athena/mongodb/domain/assetType/AssetType.java <==
package com.digiwin.athena.mongodb.domain.assetType;

import com.alibaba.fastjson.JSONObject;
import com.digiwin.athena.dto.action.MultiLanguageDTO;
import com.digiwin.athena.mongodb.domain.ApiInfo;
import com.digiwin.athena.mongodb.domain.DataCollectConfig;
import com.digiwin.athena.mongodb.domain.PublishAble;
import lombok.Data;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 资产类型
 */
@Data
@Document(collection = "assetType")
public class AssetType implements PublishAble {

    //草稿draft、已上架online、已下架offline
    public static final String STATUS_DRAFT = "draft";
    public static final String STATUS_ONLINE = "online";
    public static final String STATUS_OFFLINE = "offline";

    @Id
    private String objId;

    private String type;

    private String name;

    private String version="1.0";

    /**
     * 大类
     */
    private String category;

    /**
     * 资产归属
     */
    private String owner;

    /**
     * status|草稿draft、已上架online、已下架offline
     */
    private String status=STATUS_DRAFT;

    private String description;

    private String docUrl;

    private String icon;

    /**
     * 资产操作api
     */
    private List<ApiInfo> apiList;

    private List<ApiInfo> openApiList;

    private JSONObject metadata;

    private Date publishTime;

    private List<JSONObject> dependencyRule;
    private List<JSONObject> manageContextRule;
    private JSONObject dataCollectConfig;
    private Map<String, MultiLanguageDTO> lang;

    private JSONObject rowDataPermission;

    private String createBy;
    private String editBy;
    private Date createDate;
    private Date editDate;

    private Boolean canReference = false;
    /**
     * 能否复制
     */
    private Boolean canCopy = false;

}
